﻿using System;
using System.Globalization;
using System.Linq;
using System.Runtime.InteropServices;
using System.Text;
using System.Threading;

class Program
{
	private static class UnsafeNativeMethods
	{
		public const uint MB_OK = 0;

		[DllImport("user32", CharSet = CharSet.Ansi, ExactSpelling = true, SetLastError = true)]
		public static extern int MessageBoxA (IntPtr hWnd, string lpText, string lpCaption, uint uType);

		[DllImport("user32", CharSet = CharSet.Ansi, ExactSpelling = true, SetLastError = true)]
		public static extern int MessageBoxA (IntPtr hWnd, byte[] lpText, string lpCaption, uint uType);
	}

	static void Main (string[] args)
	{
		var cultureNames = new[] { "ja-JP", "en-US", "el-GR", "ko-KR", "ru-RU" };
		var cultures = cultureNames.Select(c => CultureInfo.GetCultureInfo(c)).ToArray();
		var encodings = cultures.Select(c => Encoding.GetEncoding(c.TextInfo.ANSICodePage)).ToArray();

		const string text = "あ°ÆαㅀБ";

		foreach (var culture in cultures)
		{
			Thread.CurrentThread.CurrentCulture = culture;
			Thread.CurrentThread.CurrentUICulture = culture;

			foreach (var encoding in encodings)
			{
				UnsafeNativeMethods.MessageBoxA(
					IntPtr.Zero,
					text,
					String.Format("culture: {0}", culture.Name),
					UnsafeNativeMethods.MB_OK);
				UnsafeNativeMethods.MessageBoxA(
					IntPtr.Zero,
					encoding.GetBytes(text + '\0'),
					String.Format("culture: {0} / encoding: {1}", culture.Name, encoding.BodyName),
					UnsafeNativeMethods.MB_OK);
			}
		}

		Console.WriteLine();
		Console.WriteLine("finished.");
		Console.ReadLine();
	}
}
